# 010_bondDebt 실험 현황

## 실험 목록
| 파일 | 설명 | 결과 |
|------|------|------|
| 001_explore.py | 삼성전자/현대차/신한지주 채무증권 섹션 탐색 | 10셀 표준 구조 확인 |
| 003_parser.py | 파서 개발 + 10종목 검증 | 8/10 성공 (2개 채무증권 없음) |
| 004_fullTest.py | 전체 종목 테스트 | 100% (102+125 해당없음) |

## 결론
- "증권의 발행을 통한 자금조달에 관한 사항" 섹션에서 채무증권 발행실적 추출
- 10셀 구조: 발행회사/증권종류/발행방법/발행일자/권면총액/이자율/평가등급/만기일/상환여부/주관회사
- 채무증권 미발행 기업은 빈 테이블 또는 "해당사항 없음"으로 표기
- finance/bond/ 패키지화 완료
